cd "...\replication package_latest"

ssc install estout

** use table1 regression data_short period.csv, copy the data into Stata's data editor

gen datevar = date(date,"MDY")

format datevar %td

encode country, generate(country2)

bcal create equity, from(datevar) purpose(mukticountry equity) generate(equitydate) replace

bcal load equity

*rename stockmarketpercentagechangefromf stock_market_deviation

*rename workplace_percent_change_from_ba workmobilitydeviation


xtset   country2 equitydate

bysort country (equitydate): g smd_l1 = smd[_n-1]
bysort country (equitydate): g smd_l2 = smd[_n-2]
bysort country (equitydate): g smd_l3 = smd[_n-3]
bysort country (equitydate): g smd_l4 = smd[_n-4]
bysort country (equitydate): g smd_l5 = smd[_n-5]
bysort country (equitydate): g smd_l6 = smd[_n-6]
bysort country (equitydate): g smd_l7 = smd[_n-7]



bysort country (equitydate): g wmd_l1 = wmd[_n-1]

gen d_wmd_t = wmd - wmd_l1
gen d_smd_t1 = smd_l1 - smd_l2
gen d_smd_t2 = smd_l2 - smd_l3
gen d_smd_t3 = smd_l3 - smd_l4
gen d_smd_t4 = smd_l4 - smd_l5
gen d_smd_t5 = smd_l5 - smd_l6
gen d_smd_t6 = smd_l6 - smd_l7

**** select correct dates 03/12/2020-03/23/2020
keep if datevar > date("11/3/2020", "DMY")
keep if datevar < date("24/3/2020", "DMY")

** regress 1: WMD_ct = constant +b*SMD_c,t-1 + error

reg wmd smd_l1
eststo

** regress 2: WMD_ct = country fixed effct +b*SMD_c,t-1 + error
reg wmd smd_l1 i.country2, nocon
eststo

** regress 3: WMD_ct = date fixed effct +b*SMD_c,t-1 + error
reg wmd smd_l1 i.equitydate, nocon
eststo

** regress 4: WMD_ct = date fixed effct +b*SMD_c,t-1 + country fixed effect +  error
reg wmd smd_l1 i.equitydate i.country2, nocon
eststo


** regress 5,6: delta(wmd_ct) = constant + sum_{j=0 to J)b*delta(smd_c,t-1-j) + error

**J=5, regression 5 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6
eststo

**J=5, regression 6 with time effect**
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6 i.equitydate,nocon
eststo


esttab using "table 1 result.rtf", se(2) ar2(2) b(2) star(* .1 ** .05 *** .01) replace

eststo clear


**** joint test of individual coefficients *****
**J=3 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4

test d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4

**J=5 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6

test d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6

reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6 i.equitydate,nocon
test d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6


*** sum of individual coefficients ****
**J=5 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6
lincom d_smd_t1 + d_smd_t2 + d_smd_t3 + d_smd_t4+ d_smd_t5 + d_smd_t6


**J=5 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6 i.equitydate,nocon
lincom d_smd_t1 + d_smd_t2 + d_smd_t3 + d_smd_t4 + d_smd_t5 + d_smd_t6

reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6 d_smd_t7 d_smd_t8 d_smd_t9 d_smd_t10 i.equitydate,nocon
lincom d_smd_t1 + d_smd_t2 + d_smd_t3 + d_smd_t4 + d_smd_t5 + d_smd_t6 + d_smd_t7+ d_smd_t8 +d_smd_t9 +d_smd_t10

**** joint test of sum of individual coefficients *****
**J=3 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4

test _b[d_smd_t1] + _b[d_smd_t2] +_b[d_smd_t3] + _b[d_smd_t4] =0

**J=5 **
reg d_wmd_t d_smd_t1 d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6

test d_smd_t1+d_smd_t2 d_smd_t3 d_smd_t4 d_smd_t5 d_smd_t6
